require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe
module UU

  # Module Finman
  module Finman

    # Module of finman Financial transaction
    module FinancialTransaction

      # DTO for setAttributes command of Financial Transaction.
      class PaymentCopySetAttributes < UU::OS::REST::DTO



        # Number of credit account.
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_number

        # UESURI of credit account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_account_uri

        # UESURI of credit financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_financial_category_uri

        # Number of debit account.
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_number

        # UESURI of debit account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_account_uri

        # UESURI of debit financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_financial_category_uri

        # Code of income item.
        # @param [String]
        # @return [String]
        attr_accessor :income_item_code

        # Code of cost item.
        # @param [String]
        # @return [String]
        attr_accessor :cost_item_code


        def cost_item_code
          attributes[:costItemCode]
        end

        def cost_item_code=(val)
          attributes[:costItemCode] = val
        end

        def credit_account_number
          attributes[:creditAccountNumber]
        end

        def credit_account_number=(val)
          attributes[:creditAccountNumber] = val
        end

        def credit_account_uri
          attributes[:creditAccountUri]
        end

        def credit_account_uri=(val)
          if val
            attributes[:creditAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditAccountUri] = nil
          end
        end

        def credit_financial_category_uri
          attributes[:creditFinancialCategoryUri]
        end

        def credit_financial_category_uri=(val)
          if val
            attributes[:creditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditFinancialCategoryUri] = nil
          end
        end

        def debit_account_number
          attributes[:debitAccountNumber]
        end

        def debit_account_number=(val)
          attributes[:debitAccountNumber] = val
        end

        def debit_account_uri
          attributes[:debitAccountUri]
        end

        def debit_account_uri=(val)
          if val
            attributes[:debitAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitAccountUri] = nil
          end
        end

        def debit_financial_category_uri
          attributes[:debitFinancialCategoryUri]
        end

        def debit_financial_category_uri=(val)
          if val
            attributes[:debitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitFinancialCategoryUri] = nil
          end
        end

        def income_item_code
          attributes[:incomeItemCode]
        end

        def income_item_code=(val)
          attributes[:incomeItemCode] = val
        end

      end
    end
  end
end

